@@ -20,11 +20,17 @@ from typing import Dict, Type
 
 from .base import ConnectionServiceTransport
 from .grpc import ConnectionServiceGrpcTransport
+from .grpc_asyncio import ConnectionServiceGrpcAsyncIOTransport
 
 
 # Compile a registry of transports.
 _transport_registry = OrderedDict()  # type: Dict[str, Type[ConnectionServiceTransport]]
 _transport_registry["grpc"] = ConnectionServiceGrpcTransport
+_transport_registry["grpc_asyncio"] = ConnectionServiceGrpcAsyncIOTransport
 
 
-__all__ = ("ConnectionServiceTransport", "ConnectionServiceGrpcTransport")
+__all__ = (
+    "ConnectionServiceTransport",
+    "ConnectionServiceGrpcTransport",
+    "ConnectionServiceGrpcAsyncIOTransport",
+)
